==> asm-1.5.2.tar.gz: asm-1.5.2/src/org/objectweb/asm/tree/MultiANewArrayInsnNode.java <==
/***
 * ASM: a very small and fast Java bytecode manipulation framework
 * Copyright (c) 2000,2002,2003 INRIA, France Telecom
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.objectweb.asm.tree;

import org.objectweb.asm.Constants;
import org.objectweb.asm.CodeVisitor;

/**
 * A node that represents a MULTIANEWARRAY instruction.
 * 
 * @author Eric Bruneton
 */

public class MultiANewArrayInsnNode extends AbstractInsnNode {

  /**
   * An array type descriptor (see {@link org.objectweb.asm.Type Type}).
   */

  public String desc;

  /**
   * Number of dimensions of the array to allocate.
   */

  public int dims;

  /**
   * Constructs a new {@link MultiANewArrayInsnNode MultiANewArrayInsnNode}
   * object.
   *
   * @param desc an array type descriptor (see {@link org.objectweb.asm.Type
   *      Type}).
   * @param dims number of dimensions of the array to allocate.
   */

  public MultiANewArrayInsnNode (final String desc, final int dims) {
    super(Constants.MULTIANEWARRAY);
    this.desc = desc;
    this.dims = dims;
  }

  public void accept (final CodeVisitor cv) {
    cv.visitMultiANewArrayInsn(desc, dims);
  }
}

==> asm-2.0.tar.gz: asm-2.0/src/org/objectweb/asm/tree/MultiANewArrayInsnNode.java <==
/***
 * ASM: a very small and fast Java bytecode manipulation framework
 * Copyright (c) 2000-2005 INRIA, France Telecom
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.objectweb.asm.tree;

import org.objectweb.asm.Opcodes;
import org.objectweb.asm.MethodVisitor;

/**
 * A node that represents a MULTIANEWARRAY instruction.
 * 
 * @author Eric Bruneton
 */

public class MultiANewArrayInsnNode extends AbstractInsnNode {

  /**
   * An array type descriptor (see {@link Type}).
   */

  public String desc;

  /**
   * Number of dimensions of the array to allocate.
   */

  public int dims;

  /**
   * Constructs a new {@link MultiANewArrayInsnNode}.
   *
   * @param desc an array type descriptor (see {@link Type}).
   * @param dims number of dimensions of the array to allocate.
   */

  public MultiANewArrayInsnNode (final String desc, final int dims) {
    super(Opcodes.MULTIANEWARRAY);
    this.desc = desc;
    this.dims = dims;
  }

  public void accept (final MethodVisitor mv) {
    mv.visitMultiANewArrayInsn(desc, dims);
  }

  public int getType () {
    return MULTIANEWARRAY_INSN;
  }
}
